Module effect

Module effect 

Structs

CT_EffectList
DrawingML a:effectLst with an outer shadow and preserved other effects.
CT_OuterShadowEffect
Modelled properties of one DrawingML a:outerShdw effect.

Enums

EffectError
Errors produced while parsing or writing DrawingML effects.
RectAlignment
DrawingML rectangle alignment used as the origin of a shadow transform.

Type Aliases

Result