pub struct CT_EffectList {
pub outer_shadow: Option<CT_OuterShadowEffect>,
/* private fields */
}Expand description
DrawingML a:effectLst with an outer shadow and preserved other effects.
Fields
outer_shadow: Option<CT_OuterShadowEffect>Implementations
Sourceimpl CT_EffectList
impl CT_EffectList
Sourcepub fn from_xml(xml: &[u8]) -> Result<Self>
pub fn from_xml(xml: &[u8]) -> Result<Self>
Parses one complete a:effectLst with any namespace prefix.
Sourcepub fn to_xml(&self) -> Result<Vec<u8>>
pub fn to_xml(&self) -> Result<Vec<u8>>
Writes this list with a fixed root prefix and the shadow in schema order.
Sourcepub fn write_xml<W: Write>(&self, writer: &mut Writer<W>) -> Result<()>
pub fn write_xml<W: Write>(&self, writer: &mut Writer<W>) -> Result<()>
Writes this effect list into an existing XML writer.
pub fn raw_children(&self) -> &OrderedRawChildren
Sourcepub fn has_unmodelled_placeholder_color(&self) -> bool
pub fn has_unmodelled_placeholder_color(&self) -> bool
Reports an unresolved placeholder colour inside an opaque effect child.