pub struct CT_CustomGeometry2D {
pub text_rectangle: Option<CT_GeomRect>,
/* private fields */
}Fields
text_rectangle: Option<CT_GeomRect>Implementations
Sourceimpl CT_CustomGeometry2D
impl CT_CustomGeometry2D
Sourcepub fn from_xml(xml: &[u8]) -> Result<Self, GeometryError>
pub fn from_xml(xml: &[u8]) -> Result<Self, GeometryError>
Parses one complete a:custGeom element with any namespace prefix.
Sourcepub fn from_element(
reader: &mut Reader<&[u8]>,
start: &BytesStart<'_>,
) -> Result<Self, GeometryError>
pub fn from_element( reader: &mut Reader<&[u8]>, start: &BytesStart<'_>, ) -> Result<Self, GeometryError>
Parses an a:custGeom after the caller consumed its start event.
pub fn adjust_values(&self) -> &[Guide]
pub fn guides(&self) -> &[Guide]
pub fn paths(&self) -> &[CT_Path2D]
Sourcepub fn to_xml(&self) -> Result<Vec<u8>, GeometryError>
pub fn to_xml(&self) -> Result<Vec<u8>, GeometryError>
Writes with the canonical a: prefix and DrawingML schema order.
Sourcepub fn evaluate(
&self,
overrides: &BTreeMap<String, f64>,
) -> Result<EvaluatedCustomGeometry, GeometryError>
pub fn evaluate( &self, overrides: &BTreeMap<String, f64>, ) -> Result<EvaluatedCustomGeometry, GeometryError>
Evaluates all paths and the text rectangle in each path’s coordinate space.
Sourcepub fn evaluate_with_size(
&self,
overrides: &BTreeMap<String, f64>,
size: (f64, f64),
) -> Result<EvaluatedCustomGeometry, GeometryError>
pub fn evaluate_with_size( &self, overrides: &BTreeMap<String, f64>, size: (f64, f64), ) -> Result<EvaluatedCustomGeometry, GeometryError>
Evaluates paths with the containing shape size on omitted coordinate axes.