pub struct CT_Table {
pub properties: Option<CT_TableProperties>,
pub grid: CT_TableGrid,
pub rows: Vec<CT_TableRow>,
/* private fields */
}Expand description
One DrawingML a:tbl with typed grid, rows, cells, and banding properties.
Fields
properties: Option<CT_TableProperties>grid: CT_TableGridrows: Vec<CT_TableRow>Implementations
Sourceimpl CT_Table
impl CT_Table
Sourcepub fn new(rows: usize, columns: usize, width: Emu, height: Emu) -> Result<Self>
pub fn new(rows: usize, columns: usize, width: Emu, height: Emu) -> Result<Self>
Creates a rectangular table using truncating quotients and assigns each remainder to the final column or row.