pub enum Fill {
NoFill(NoFill),
Solid(SolidFill),
Gradient(GradientFill),
Pattern(PatternFill),
Blip(BlipFill),
}Expand description
One of the five DrawingML fill families.
Variants
Implementations
Sourceimpl Fill
impl Fill
Sourcepub fn from_xml(xml: &[u8]) -> Result<Self>
pub fn from_xml(xml: &[u8]) -> Result<Self>
Parses one complete fill element with any namespace prefix.
Sourcepub fn from_element(
reader: &mut Reader<&[u8]>,
start: &BytesStart<'_>,
) -> Result<Self>
pub fn from_element( reader: &mut Reader<&[u8]>, start: &BytesStart<'_>, ) -> Result<Self>
Parses a fill after the caller has consumed its start event.
Sourcepub fn from_empty_element(start: &BytesStart<'_>) -> Result<Self>
pub fn from_empty_element(start: &BytesStart<'_>) -> Result<Self>
Parses a self-closing fill element.