Skip to main contentModule line
Source - CT_LineProperties
- DrawingML
a:ln properties. - CustomDash
- Custom line dash stops in document order.
- DashStop
- One custom painted and unpainted dash pair, in thousandths of a percent.
- LineEnd
- One head or tail endpoint and its optional dimensions.
- PresetDash
- A preset line dash and any extension children inside it.
- LineCap
- DrawingML line cap behavior.
- LineDash
- Either a DrawingML preset or custom line dash.
- LineEndSize
- DrawingML line endpoint width or length.
- LineEndType
- DrawingML line endpoint shape.
- LineError
- Errors produced while parsing or writing DrawingML line properties.
- LineJoin
- DrawingML line join behavior.
- ST_PresetLineDashVal
- The eleven values in
ST_PresetLineDashVal.
- Result